@@ -99,6 +99,16 @@ def test_loads_event_data_mapped_to_detector_numbers_based_on_their_event_id(nxr
     assert 'event_time_zero' in loaded.bins.coords
 
 
+def test_loads_event_data_with_0d_detector_numbers(nxroot):
+    detector = nxroot.create_class('detector0', NX_class.NXdetector)
+    detector.create_field('detector_number', sc.index(1, dtype='int64'))
+    create_event_data_ids_1234(detector.create_class('events', NX_class.NXevent_data))
+    assert detector.dims == []
+    assert detector.shape == []
+    loaded = detector[...]
+    assert sc.identical(loaded.bins.size().data, sc.index(2, dtype='int64'))
+
+
 def test_loads_event_data_with_2d_detector_numbers(nxroot):
     detector = nxroot.create_class('detector0', NX_class.NXdetector)
     detector.create_field('detector_number', detector_numbers_xx_yy_1234())
